@@ -1,4 +1,9 @@
-def is_semver(value: str) -> bool:
+from typing import Optional
+
+import semver
+
+
+def is_semver(value: Optional[str]) -> bool:
     """
     Checks if the given string have `:semver` suffix or not
     >>> is_semver("2.1.41-beta:semver")
@@ -7,10 +12,10 @@ def is_semver(value: str) -> bool:
     False
     """
 
-    return value[-7:] == ":semver"
+    return value is not None and value[-7:] == ":semver"
 
 
-def remove_semver_suffix(value: str) -> str:
+def remove_semver_suffix(value: semver.Version) -> str:
     """
     Remove the semver suffix(i.e: last 7 characters) from the given value
     >>> remove_semver_suffix("2.1.41-beta:semver")
@@ -18,4 +23,4 @@ def remove_semver_suffix(value: str) -> str:
     >>> remove_semver_suffix("2.1.41:semver")
     '2.1.41'
     """
-    return value[:-7]
+    return str(value)[:-7]
